#!/bin/bash

if [ x$usearch == x ] ; then
	echo Must set \$usearch >> /dev/stderr
	exit 1
fi

out=../out

rm -rf $out
mkdir -p $out

$usearch -fastq_mergepairs ../fq/ERR699289_1.fastq -reverse ../fq/ERR699289_2.fastq -tabbedout $out/merge_tab.txt -report $out/merge_report.txt

for run in `grep ERR ../info/sample_run.txt | cut -f2`
do
	sample=`grep $run ../info/sample_run.txt | cut -f1`
	$u64 -fastq_mergepairs ../fq/${run}_1.fastq -reverse ../fq/${run}_2.fastq -relabel $sample. \
	  -fastq_minmergelen 100 -fastqout $out/run_$run.fq
done

cat $out/run_*.fq > $out/merged.fq

$usearch -fastq_filter $out/merged.fq -fastq_maxee 1.0 -fastaout $out/filtered.fa -relabel Filt -log $out/filter.log

$usearch -derep_fulllength $out/filtered.fa -sizeout -relabel Uniq -fastaout $out/uniques.fa -log $out/derep.log

$usearch -cluster_otus $out/uniques.fa -minsize 2 -otus $out/otus.fa -relabel Otu -log $out/cluster_otus.log

$usearch -utax $out/otus.fa -db ../utax/utax_its2.udb -strand both \
  -fastaout $out/otus_tax.fa -utax_cutoff 0.9 -utaxout $out/utax.txt -log $out/utax.log

$usearch -usearch_global $out/merged.fq -db $out/otus_tax.fa -strand plus -id 0.97 -log $out/make_otutab.log \
  -otutabout $out/otutab.txt -biomout $out/otutab.json -mothur_shared_out $out/otutab.mothur 
